[![Build Status](https://github.com/medialab/pelote/workflows/Tests/badge.svg)](https://github.com/medialab/pelote/actions)

# Pelote

TODO...

## Installation

You can install `pelote` with pip with the following command:

```
pip install pelote
```

## Usage

WIP...
